@@ -1,8 +1,8 @@
-## which.edge.R (2007-09-11)
+## which.edge.R (2009-05-10)
 
 ##   Identifies Edges of a Tree
 
-## Copyright 2004-2007 Emmanuel Paradis
+## Copyright 2004-2009 Emmanuel Paradis
 
 ## This file is part of the R-package `ape'.
 ## See the file ../COPYING for licensing issues.
@@ -28,7 +28,7 @@ getMRCA <- function(phy, tip)
 
 which.edge <- function(phy, group)
 {
-    if (class(phy) != "phylo")
+    if (!inherits(phy, "phylo"))
       stop('object "phy" is not of class "phylo"')
     if (is.character(group))
       group <- which(phy$tip.label %in% group)
